import React, { useState, useEffect } from 'react';
import { Tree, Table, Space, message, Modal, Form, Input } from 'antd';
import {
  UserAddOutlined,
  UsergroupAddOutlined,
  FileAddTwoTone,
  FolderAddTwoTone,
  EditTwoTone,
  DeleteTwoTone,
} from '@ant-design/icons';
import { PageContainer } from '@ant-design/pro-layout';
// import classnames from 'classnames';
import { get, post } from '../../services';
import styles from './UserManage.less';

const columns = [
  {
    title: '登录名',
    dataIndex: 'loginName',
    key: 'loginName',
  },
  {
    title: '用户姓名',
    dataIndex: 'userName',
    key: 'userName',
  },
  {
    title: '手机号码',
    dataIndex: 'phone',
    key: 'phone',
  },
  {
    title: '钉钉账户',
    dataIndex: 'ddid',
    key: 'ddid',
  },
  {
    title: '微信账户',
    dataIndex: 'wxid',
    key: 'wxid',
  },
  {
    title: '操作',
    key: 'action',
    render: (text, record) => (
      <Space size="middle">
        <a>关联角色 {record.name}</a>
        <a>更改机构</a>
        <a>编辑</a>
        <a>冻结</a>
        <a>删除</a>
      </Space>
    ),
  },
];

const UserManage = () => {
  const [tableLoading, setTableLoading] = useState(false);
  const [treeData, setTreeData] = useState([]); // 用户机构树
  const [tableData, setTableData] = useState([]); // 用户表
  const [userVisible, setUserVisible] = useState(false);
  const [orgTitle, setOrgTitle] = useState('机构');
  const [orgID, setOrgID] = useState('机构');
  const mapTree = org => {
    const haveChildren = Array.isArray(org.children) && org.children.length > 0;
    return {
      title: (
        <div className={styles.iconWraper1}>
          {org.text}
          <FileAddTwoTone
            onClick={e => addUser(e, org.text, org.id)}
            title="添加用户"
          />
          <FolderAddTwoTone onClick={addUser} title="添加下级机构" />
          <EditTwoTone onClick={addUser} title="编辑" />
          <DeleteTwoTone onClick={addUser} title="删除" />
        </div>
      ),
      key: org.id,
      // icon: <CaretDownOutlined />,
      // 判断它是否存在子集，若果存在就进行再次进行遍历操作，知道不存在子集便对其他的元素进行操作
      children: haveChildren ? org.children.map(i => mapTree(i)) : [],
    };
  };

  // 获取用户机构列表
  useEffect(() => {
    setTableLoading(true);
    get(`/Cityinterface/rest/services/OMS.svc/U_GetOUTree`, {
      _version: 9999,
      node: -1,
    })
      .then(res => {
        setTableLoading(false);
        if (res.length > 0) {
          const orgTree = res.map(org => mapTree(org));
          setTreeData(orgTree);
        }
      })
      .catch(err => {
        setTableLoading(false);
        message.error(err);
      });
  }, []);

  // 获取当前机构下所有用户
  const onSelect = props => {
    setTableLoading(true);
    get(`/Cityinterface/rest/services/OMS.svc/U_GetOneOUUserListNew`, {
      _version: 9999,
      OUID: props[0],
    })
      .then(res => {
        setTableLoading(false);
        if (res.root.length > 0) {
          setTableData(res.root);
        }
      })
      .catch(err => {
        setTableLoading(false);
        message.error(err);
      });
  };

  const addUser = (e, title, id) => {
    e.stopPropagation();
    setUserVisible(true);
    setOrgTitle(`在${title}下添加用户`);
    setOrgID(id);
  };
  const submitAddUser = props => {
    setUserVisible(false);
  };

  return (
    <PageContainer>
      <div
        style={{
          width: '20%',
          height: 'calc(100vh - 194px)',
          background: 'white',
          float: 'left',
        }}
      >
        <div style={{ padding: '8px' }}>
          机构列表
          <UsergroupAddOutlined style={{ color: '#1890ff', float: 'right' }} />
        </div>
        <Tree
          showLine="true"
          showIcon="true"
          loading={tableLoading}
          onSelect={onSelect}
          treeData={treeData}
        />
      </div>
      <div
        style={{
          width: '79%',
          height: 'calc(100vh - 194px)',
          background: 'white',
          float: 'right',
        }}
      >
        <Table
          columns={columns}
          dataSource={tableData}
          loading={tableLoading}
        />
      </div>
      <Modal
        title={orgTitle}
        visible={userVisible}
        onOk={submitAddUser}
        onCancel={() => setUserVisible(false)}
        okText="确认"
        cancelText="取消"
      >
        {/* <div style={{ width: '20%', float: 'left' }}>
          <UserAddOutlined style={{ color: 'blue', width: '40px' }} />
        </div> */}
        {/* <div style={{ width: '80%', float: 'right' }}> */}
        <Form>
          <Form.Item
            name="loginName"
            label="登录名称"
            rules={[
              {
                required: true,
              },
            ]}
          >
            <Input />
          </Form.Item>
          <Form.Item
            name="password"
            label="账户密码"
            rules={[
              {
                required: true,
              },
            ]}
          >
            <Input />
          </Form.Item>
          <Form.Item name="userName" label="用 户 姓 名">
            <Input />
          </Form.Item>
          <Form.Item name="phone" label="手 机 号 码">
            <Input />
          </Form.Item>
          <Form.Item name="email" label="电 子 邮 件">
            <Input />
          </Form.Item>
          <Form.Item name="ddid" label="钉 钉 账 户">
            <Input />
          </Form.Item>
          <Form.Item name="wxid" label="微 信 账 户">
            <Input />
          </Form.Item>
        </Form>
        {/* </div> */}
      </Modal>
    </PageContainer>
  );
};

export default UserManage;
